<?php

namespace Drupal\module_instructions\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Extension\ExtensionPathResolver;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Base controller for the 'module instructions' module.
 */
class ModuleInstructionsController extends ControllerBase {

  /**
   * Returns the extension.path.resolver service.
   *
   * @var \Drupal\Core\Extension\ExtensionPathResolver
   */
  protected $pathResolver;

  /**
   * Constructs a ModuleInstructionsController object.
   *
   * @param \Drupal\Core\Extension\ExtensionPathResolver $path_resolver
   *   Factory for getting extension lists by type.
   */
  public function __construct(ExtensionPathResolver $path_resolver) {
    $this->pathResolver = $path_resolver;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('extension.path.resolver')
    );
  }

  /**
   * Creates a title for the instruction page.
   */
  public function getTitle($module, $file) {
    return $this->t('@module (@file)', ['@module' => $module, '@file' => $file]);
  }

  /**
   * Displays the instruction file.
   */
  public function instruction($module, $file) {
    $fullpath = $this->pathResolver->getPath('module', $module) . '/' . $file;

    $filter = (object) [];
    $filter->settings = [
      'filter_url_length' => 256,
    ];

    if (file_exists($fullpath)) {
      $content = file_get_contents($fullpath);

      return [
        '#markup' => '<pre>' . check_markup(_filter_url($content, $filter), 'full_html') . '</pre>',
      ];
    }

    throw new NotFoundHttpException();
  }

}
